@@ -13,25 +13,22 @@
 
 namespace phpbb\db\migration\data\v30x;
 
-class release_3_0_12 extends \phpbb\db\migration\migration
+class release_3_0_1 extends \phpbb\db\migration\migration
 {
 	public function effectively_installed()
 	{
-		return phpbb_version_compare($this->config['version'], '3.0.12', '>=') && phpbb_version_compare($this->config['version'], '3.1.0-dev', '<');
+		return phpbb_version_compare($this->config['version'], '3.0.1', '>=');
 	}
 
 	static public function depends_on()
 	{
-		return array('\phpbb\db\migration\data\v30x\release_3_0_12_rc3');
+		return array('\phpbb\db\migration\data\v30x\release_3_0_1_rc1');
 	}
 
 	public function update_data()
 	{
 		return array(
-			array('if', array(
-				phpbb_version_compare($this->config['version'], '3.0.12', '<'),
-				array('config.update', array('version', '3.0.12')),
-			)),
+			array('config.update', array('version', '3.0.1')),
 		);
 	}
 }
