@@ -253,6 +253,16 @@ class fulltext_native extends \phpbb\search\base
 						$keywords[$i] = ' ';
 					break;
 					case '-':
+						// Ignore hyphen if followed by a space
+						if (isset($keywords[$i + 1]) && $keywords[$i + 1] == ' ')
+						{
+							$keywords[$i] = ' ';
+						}
+						else
+						{
+							$space = $keywords[$i];
+						}
+					break;
 					case '+':
 						$space = $keywords[$i];
 					break;
@@ -405,7 +415,7 @@ class fulltext_native extends \phpbb\search\base
 				}
 
 				// a group of words of which at least one word should be in every resulting post
-				if ($word[0] == '(')
+				if (isset($word[0]) && $word[0] == '(')
 				{
 					$word = array_unique(explode('|', substr($word, 1, -1)));
 				}
@@ -898,9 +908,6 @@ class fulltext_native extends \phpbb\search\base
 			switch ($this->db->get_sql_layer())
 			{
 				case 'mysqli':
-
-					// 3.x does not support SQL_CALC_FOUND_ROWS
-					// $sql_array['SELECT'] = 'SQL_CALC_FOUND_ROWS ' . $sql_array['SELECT'];
 					$is_mysql = true;
 
 				break;
@@ -958,16 +965,10 @@ class fulltext_native extends \phpbb\search\base
 			);
 		}
 
-		// if using mysql and the total result count is not calculated yet, get it from the db
-		if (!$total_results && $is_mysql)
-		{
-			// Also count rows for the query as if there was not LIMIT. Add SQL_CALC_FOUND_ROWS to SQL
-			$sql_array['SELECT'] = 'SQL_CALC_FOUND_ROWS ' . $sql_array['SELECT'];
-		}
-
 		$sql_array['WHERE'] = implode(' AND ', $sql_where);
 		$sql_array['GROUP_BY'] = ($group_by) ? (($type == 'posts') ? 'p.post_id' : 'p.topic_id') . ', ' . $sort_by_sql[$sort_key] : '';
 		$sql_array['ORDER_BY'] = $sql_sort;
+		$sql_array['SELECT'] .= $sort_by_sql[$sort_key] ? ", {$sort_by_sql[$sort_key]}" : '';
 
 		unset($sql_where, $sql_sort, $group_by);
 
@@ -980,10 +981,10 @@ class fulltext_native extends \phpbb\search\base
 		}
 		$this->db->sql_freeresult($result);
 
+		// If using mysql and the total result count is not calculated yet, get it from the db
 		if (!$total_results && $is_mysql)
 		{
-			// Get the number of results as calculated by MySQL
-			$sql_count = 'SELECT FOUND_ROWS() as total_results';
+			$sql_count = str_replace("SELECT {$sql_array['SELECT']}", "SELECT COUNT(DISTINCT {$sql_array['SELECT']}) as total_results", $sql);
 			$result = $this->db->sql_query($sql_count);
 			$total_results = (int) $this->db->sql_fetchfield('total_results');
 			$this->db->sql_freeresult($result);
@@ -1005,7 +1006,6 @@ class fulltext_native extends \phpbb\search\base
 				$id_ary[] = (int) $row[(($type == 'posts') ? 'post_id' : 'topic_id')];
 			}
 			$this->db->sql_freeresult($result);
-
 		}
 
 		// store the ids, from start on then delete anything that isn't on the current page because we only need ids for one page
@@ -1137,6 +1137,7 @@ class fulltext_native extends \phpbb\search\base
 		}
 
 		$select = ($type == 'posts') ? 'p.post_id' : 't.topic_id';
+		$select .= $sort_by_sql[$sort_key] ? ", {$sort_by_sql[$sort_key]}" : '';
 		$is_mysql = false;
 
 		/**
@@ -1192,7 +1193,6 @@ class fulltext_native extends \phpbb\search\base
 			switch ($this->db->get_sql_layer())
 			{
 				case 'mysqli':
-//					$select = 'SQL_CALC_FOUND_ROWS ' . $select;
 					$is_mysql = true;
 				break;
 
@@ -1285,15 +1285,9 @@ class fulltext_native extends \phpbb\search\base
 
 		if (!$total_results && $is_mysql)
 		{
-			// Count rows for the executed queries. Replace $select within $sql with SQL_CALC_FOUND_ROWS, and run it.
-			$sql_calc = str_replace('SELECT ' . $select, 'SELECT SQL_CALC_FOUND_ROWS ' . $select, $sql);
-
-			$result = $this->db->sql_query($sql_calc);
-			$this->db->sql_freeresult($result);
-
-			$sql_count = 'SELECT FOUND_ROWS() as total_results';
+			$sql_count = str_replace("SELECT $select", "SELECT COUNT(*) as total_results", $sql);
 			$result = $this->db->sql_query($sql_count);
-			$total_results = (int) $this->db->sql_fetchfield('total_results');
+			$total_results = ($type == 'posts') ? (int) $this->db->sql_fetchfield('total_results') : count($this->db->sql_fetchrowset($result));
 			$this->db->sql_freeresult($result);
 
 			if (!$total_results)
